@@ -2,12 +2,12 @@ package PPI::Xref;
 
 use v5.14;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 use strict;
 use warnings;
 
-use PPI::Document;
+use PPI;
 
 # We will use file ids (integers) instead of filenames, mainly for
 # space savings, but also speed, and only convert back to filenames
